import type { UploadFile, UploadProps } from 'ant-design-vue';
import type { FormSchemaGetter } from '#/adapter/form';
import type { VxeGridProps } from '#/adapter/vxe-table';

import { DictEnum } from '@vben/constants';
import { getPopupContainer } from '@vben/utils';
import { useAppConfig } from '@vben/hooks';
import { useAccessStore } from '@vben/stores';
import { ref } from 'vue';
import { getDictOptions } from '#/utils/dict';
// import { OptionsItem } from ""

export const querySchema: FormSchemaGetter = () => [
  {
    component: 'Input',
    fieldName: 'workName',
    label: '工作名称',
  },
  {
    component: 'Input',
    fieldName: 'id',
    label: '编号',
  },
  {
    component: 'Input',
    fieldName: 'responsibleDepartment',
    label: '负责部门',
  },
  {
    component: 'Select',
    componentProps: {
      getPopupContainer,
      options: getDictOptions(DictEnum.TASK_STATUS),
    },
    fieldName: 'taskStatus',
    label: '任务状态',
  },
  {
    component: 'Select',
    componentProps: {
      getPopupContainer,
      options: getDictOptions(DictEnum.ASSIGNMENT_STATUS),
    },
    fieldName: 'assignmentStatus',
    label: '分配状态',
  },
  {
    component: 'Input',
    fieldName: 'Annual',
    label: '年度',
  },
];

export const columns: VxeGridProps['columns'] = [
  { type: 'checkbox', width: 60 },
  {
    field: 'workName',
    title: '名称',
  },
  {
    field: 'id',
    title: '编号',
  },
  {
    field: 'responsibleDepartment',
    title: '负责部门',
  },
  {
    field: 'Head',
    title: '负责人',
  },
  {
    field: 'workClass',
    title: '类别',
  },
  {
    field: 'assessmentTime',
    title: '考核时间',
  },
  {
    field: 'taskStatus',
    title: '任务状态',
  },
  {
    field: 'assignmentStatus',
    title: '分配状态',
  },
  {
    field: 'Annual',
    title: '年度',
  },
  {
    field: 'workProgress',
    title: '工作进度',
  },
  {
    field: 'action',
    fixed: 'right',
    slots: { default: 'action' },
    title: '操作',
    width: 180,
  },
];
// 表单
export const drawerSchema: FormSchemaGetter = () => [
  {
    component: 'Input',
    fieldName: 'workName',
    label: '工作名称',
    rules: 'required'
  },
  {
    component: 'Input',
    fieldName: 'workClass',
    label: '工作类别',
    rules: 'required',
  },
  {
    component: 'Textarea',
    fieldName: 'workContent',
    label: '工作内容'
  },

  {
    component: 'Input',
    fieldName: 'projectBudget',
    label: '项目预算%',
    defaultValue: undefined
  },
  {
    component: 'Input',
    fieldName: 'amountProject',
    defaultValue: undefined,
    label: '项目金额'
  },
  {
    component: 'Select',
    componentProps: {
      getPopupContainer,
      options: []
    },
    fieldName: 'responsibleDepartment',
    label: '负责部门',
    rules: 'required',
  },
  {
    component: 'Select',
    componentProps: {
      getPopupContainer,
      options: getDictOptions(DictEnum.SYS_NORMAL_DISABLE)
    },
    fieldName: 'Head',
    label: '负责人',
  },
  {
    component: 'DatePicker',
    componentProps: {
      format: 'YYYY',
      showTime: true,
      valueFormat: 'YYYY',
      picker: "year",
      getPopupContainer,
    },
    fieldName: 'Annual',
    label: '年度',
    rules: 'required',
  },
  {
    component: 'DatePicker',
    componentProps: {
      format: 'YYYY-MM-DD',
      showTime: true,
      valueFormat: 'YYYY-MM-DD',
      getPopupContainer,
    },
    fieldName: 'assessmentTime',
    label: '考核时间',
    rules: 'required',
  },
  {
    component: 'Select',
    fieldName: 'assessmentIndicators',
    formItemClass: 'items-baseline',
    label: '考核指标',
  },
  {
    fieldName: 'File',
    component: 'NewFileUpload',
    componentProps: {
      action: uploadUrl,
      headers: headers,
      change: handleChange,
      maxSize: 20,
      onDelete:(file: UploadFile)=>{
        console.log("存在文件被删除",file)
      },
      onStartUpload:()=>{
        //开始上传
        UploadFileState.value = true
      },
      onEndUpload:()=>{
        //上传结束
        UploadFileState.value = false
      }
    },
    formItemClass: 'items-baseline',
    label: '文件上传',
  }
];

/*
  当前被上传文件的文件状态
  true —— 正在上传
  false —— 上传结束
*/
export const UploadFileState = ref(false)

const { apiURL, clientId } = useAppConfig(
  import.meta.env,
  import.meta.env.PROD,
);
const uploadUrl = `${apiURL}/knowledge/attach/upload`;
const accessStore = useAccessStore();
const headers = {
  Authorization: `Bearer ${accessStore.accessToken}`,
  clientId,
};

// 文件选取
function handleChange(res:any) {
  console.log("选取了文件")
  console.log(res)
}
